starcluster.commands.listkeypairs

Package starcluster :: Package commands :: Module listkeypairs |
[hide private]
[frames] | no frames]

# Source Code for Module starcluster.commands.listkeypairs

     1  #!/usr/bin/env python
     2
     3  from base import CmdBase
     4
     5
     6 -class CmdListKeyPairs(CmdBase):
     7      """
     8      listkeypairs
     9
    10      List all EC2 keypairs
    11      """
    12      names = ['listkeypairs', 'lk']
    13
    14 -    def execute(self, args):
    15          self.ec2.list_keypairs()
    16